# Translating

This document holds instructions to get you started with translating coala. In
order to make translating for coala easy we have set up a web UI with always up
to date strings for you.

This document provides a tutorial so you can get started fast with translating
coala. If you are already using Zanata, please go ahead and skip directly to
the "Translating coala" section.

# Registering at Zanata

You can sign up for a free Zanata account here:

https://translate.zanata.org/zanata/account/register

Please follow the instructions to activate your account.

# Joining a Language Team

Please follow the instructions at http://zanata.org/help/adding-translators/
to be added to a language team. If you are already a coala contributor you can
also request maintainership access, just drop a message to
<lasse.schuirmann@gmail.com>.

# Translating coala

Just navigate to
https://translate.zanata.org/zanata/project/view/coala/versions and start
translating.

If you need more information about the Zanata web UI, please consult
http://zanata.org/help/preparing-for-translation/ and
http://zanata.org/help/translating/ .

Note that translations for coala are reviewed. Any translation you add will
automatically added with the state "translated". If you have the right to
review translations (either given to you by the language team for your language
or by the coala maintainers) please take the time to review and approve
pending translations from time to time.

The coala maintainers will pull the translations into the main repository
from time to time.
